@@ -1,17 +1,25 @@
 """matwrap.py: wrapper around matplotlib."""
+# pylint: disable=undefined-all-variable
 
 import json
-import logging
+import warnings
 from argparse import _ArgumentGroup, Action, ArgumentParser
 from contextlib import AbstractContextManager
 from typing import Optional, Tuple, Union
 
 from pkg_resources import resource_filename
 
-from shinyutils import shiny_arg_parser
-from shinyutils.argp import KeyValuePairsType
+from shinyutils._argp import KeyValuePairsType
 
-__all__ = ["MatWrap", "Plot"]
+_WRAPPED_NAMES = ["mpl", "plt", "sns"]
+__all__ = ["MatWrap", "Plot"] + _WRAPPED_NAMES
+
+
+def __getattr__(name):
+    if name in _WRAPPED_NAMES:
+        attr = getattr(MatWrap, name)
+        return attr.__func__(MatWrap)
+    raise AttributeError
 
 
 class MatWrap:
@@ -33,7 +41,8 @@ class MatWrap:
         latex_pkgs=None,
         **rc_extra,
     ):
-        """
+        """Configure matplotlib and seaborn.
+
         Arguments:
             context: seaborn context (paper/notebook/poster).
             style: seaborn style (whitegrid, darkgrid, etc.)
@@ -129,8 +138,9 @@ class MatWrap:
 
     @staticmethod
     def set_size_tight(fig, size):
-        logging.warning(
-            "constrained_layout is enabled by default: don't use tight_layout"
+        warnings.warn(
+            "constrained_layout is enabled by default: don't use tight_layout",
+            FutureWarning,
         )
         fig.set_size_inches(*size)
         fig.tight_layout(pad=0, w_pad=0, h_pad=0)
@@ -241,4 +251,3 @@ class Plot(AbstractContextManager):
 
 
 MatWrap.configure()
-MatWrap.add_parser_config_args(shiny_arg_parser)
